package net.javase.wechat.api;

import net.javase.wechat.bean.msg.MpTempMsg;
import net.javase.wechat.enums.WxApiEnum;
import net.javase.wechat.kit.WxApiKit;
import net.javase.wechat.model.req.msg.AddTempReq;
import net.javase.wechat.model.req.msg.SubscribeMsgSend;
import net.javase.wechat.model.req.msg.UniformMsgSendReq;
import net.javase.wechat.model.resp.AddTempResp;
import net.javase.wechat.model.resp.BaseResp;

/**
 * 微信服务消息API
 *
 * @author Frank
 */
public class WxMsgApi {

	/**
	 * 下发小程序和公众号统一的服务消息
	 *
	 * @param accessToken accessToken
	 * @param req         请求信息
	 * @return {@link BaseResp} 响应信息
	 */
	public static BaseResp uniformMsgSend(String accessToken, UniformMsgSendReq req) {
		return WxApiKit.postRequest(WxApiKit.getUrl(WxApiEnum.MSG_UNIFORM_SEND, accessToken), req.toJson(), BaseResp.class);
	}

	/**
	 * 小程序订阅消息
	 *
	 * @param accessToken accessToken
	 * @param req         请求信息
	 * @return {@link BaseResp} 响应信息
	 */
	public static BaseResp subscribe(String accessToken, SubscribeMsgSend req) {
		return WxApiKit.postRequest(WxApiKit.getUrl(WxApiEnum.TMPL_SEND, accessToken), req.toJson(), BaseResp.class);
	}

	/**
	 * 小程序 组合模板并添加至帐号下的个人模板库
	 *
	 * @param accessToken accessToken
	 * @param req         请求信息
	 * @return {@link AddTempResp} 响应信息
	 */
	public static AddTempResp addTemplate(String accessToken, AddTempReq req) {
		return WxApiKit.postRequest(WxApiKit.getUrl(WxApiEnum.TMPL_ADD_TEMPLATE, accessToken), req.toJson(), AddTempResp.class);
	}

	/**
	 * 公众号 基础消息能力 发送模板消息
	 *
	 * @param accessToken access_token
	 * @param mpTempMsg   请求参数
	 * @return {@link BaseResp} 响应信息
	 */
	public static BaseResp msgTempSend(String accessToken, MpTempMsg mpTempMsg) {
		return WxApiKit.postRequest(WxApiKit.getUrl(WxApiEnum.MP_MSG_TEMP_SEND, accessToken), mpTempMsg.toJson(), BaseResp.class);
	}
}
