package net.javase.wechat.api;

import cn.hutool.http.HttpResponse;
import lombok.extern.slf4j.Slf4j;
import net.javase.wechat.enums.WxApiEnum;
import net.javase.wechat.kit.WxApiKit;
import net.javase.wechat.model.req.qr.WxaQrCodeReq;

import java.io.InputStream;

/**
 * 微信小程序二维码
 *
 * @author Frank
 */
@Slf4j
public class WxaQrApi {


	/**
	 * 获取小程序码，适用于需要的码数量极多的业务场景。通过该接口生成的小程序码，永久有效，数量暂无限制。
	 *
	 * @param req         二维码参数
	 * @param accessToken 接口accessToken
	 * @return {@link InputStream}
	 */
	public static InputStream getUnLimit(WxaQrCodeReq req, String accessToken) {
		try (HttpResponse resp = WxApiKit.postRequest(WxApiKit.getUrl(WxApiEnum.GET_WXA_CODE_UNLIMITED,
			accessToken), req.toJson()).sync()) {
			return resp.bodyStream();
		}
	}

	/**
	 * 获取小程序二维码，适用于需要的码数量较少的业务场景。通过该接口生成的小程序码，永久有效，有数量限制
	 *
	 * @param req         二维码参数
	 * @param accessToken 接口accessToken
	 * @return {@link InputStream}
	 */
	public static InputStream createQrCode(WxaQrCodeReq req, String accessToken) {
		try (HttpResponse resp = WxApiKit.postRequest(WxApiKit.getUrl(WxApiEnum.CREATE_WXA_QR_CODE,
			accessToken), req.toJson()).sync()) {
			return resp.bodyStream();
		}
	}

	/**
	 * 获取小程序码，适用于需要的码数量较少的业务场景。通过该接口生成的小程序码，永久有效，有数量限制
	 *
	 * @param req         二维码参数
	 * @param accessToken 接口accessToken
	 * @return {@link InputStream}
	 */
	public static InputStream get(WxaQrCodeReq req, String accessToken) {
		try (HttpResponse resp = WxApiKit.postRequest(WxApiKit.getUrl(WxApiEnum.GET_WXA_CODE,
			accessToken), req.toJson()).sync()) {
			return resp.bodyStream();
		}
	}


}
