package net.javase.wechat.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 微信公众平台枚举
 *
 * @author Frank
 */
@Getter
@AllArgsConstructor
public enum WxApiEnum {

	/**
	 * auth.code2Session
	 */
	CODE_SESSION("/sns/jscode2session"),

	/**
	 * auth.getAccessToken
	 */
	ACCESS_TOKEN("/cgi-bin/token"),

	OAUTH_ACCESS_TOKEN("/sns/oauth2/access_token"),

	USER_INFO("/sns/userinfo"),

	GET_PAID_UNIONID("/wxa/getpaidunionid"),

	/**
	 * 统一服务消息
	 */
	MSG_UNIFORM_SEND("/cgi-bin/message/wxopen/template/uniform_send"),

	/**
	 * 创建被分享动态消息或私密消息的 activity_id
	 */
	MSG_CREATE_ACTIVITY_ID("/cgi-bin/message/wxopen/activityid/create"),

	/**
	 * 修改被分享的动态消息
	 */
	MSG_SET_UPDATABLE_MSG("/cgi-bin/message/wxopen/updatablemsg/send"),

	/**
	 * 获取小程序二维码, 永久有效，有数量限制
	 */
	CREATE_WXA_QR_CODE("/cgi-bin/wxaapp/createwxaqrcode"),

	/**
	 * 获取小程序码, 永久有效，有数量限制
	 */
	GET_WXA_CODE("/wxa/getwxacode"),

	/**
	 * 获取小程序码, 永久有效，数量暂无限制
	 */
	GET_WXA_CODE_UNLIMITED("/wxa/getwxacodeunlimit"),

	/**
	 * 获取小程序scheme码，适用于短信、邮件、外部网页等拉起小程序的业务场景
	 */
	GET_WXA_URL_SCHEME("/wxa/generatescheme"),

	/**
	 * 组合模板并添加至帐号下的个人模板库
	 */
	TMPL_ADD_TEMPLATE("/wxaapi/newtmpl/addtemplate"),

	/**
	 * 删除帐号下的个人模板
	 */
	TMPL_DEL_TEMPLATE("/wxaapi/newtmpl/deltemplate"),

	/**
	 * 获取小程序账号的类目
	 */
	TMPL_GET_CATEGORY("/wxaapi/newtmpl/getcategory"),

	/**
	 * 获取模板标题下的关键词列表
	 */
	TMPL_GET_PUB_TEMP_KEYWORDS("/wxaapi/newtmpl/getpubtemplatekeywords"),

	/**
	 * 获取帐号所属类目下的公共模板标题
	 */
	TMPL_GET_PUB_TEMP_TITLE("/wxaapi/newtmpl/getpubtemplatetitles"),

	/**
	 * 获取当前帐号下的个人模板列表
	 */
	TMPL_GET_TEMPLATE("/wxaapi/newtmpl/gettemplate"),

	/**
	 * 发送订阅消息
	 */
	TMPL_SEND("/cgi-bin/message/subscribe/send"),

	/**
	 * 公众号模板消息 (业务通知)
	 */
	MP_MSG_TEMP_SEND("/cgi-bin/message/template/send"),

	/**
	 * 临时素材
	 */
	MEDIA_UPLOAD("/cgi-bin/media/upload"),

	JSAPI_TICKET("/cgi-bin/ticket/getticket"),

	LIVE_CREATE("/wxaapi/broadcast/room/create"),

	LIVE_GET_INFO("/wxa/business/getliveinfo"),

	LIVE_ADD_GOODS_TO_ROOM("/wxaapi/broadcast/room/addgoods"),

	LIVE_DEL_ROOM("/wxaapi/broadcast/room/deleteroom"),

	LIVE_EDIT_ROOM("/wxaapi/broadcast/room/editroom"),

	LIVE_GET_PUSH_URL("/wxaapi/broadcast/room/getpushurl"),

	LIVE_GET_SHARE_CODE("/wxaapi/broadcast/room/getsharedcode"),

	LIVE_ADD_ASSISTANT("/wxaapi/broadcast/room/addassistant"),

	LIVE_MODIFY_ASSISTANT("/wxaapi/broadcast/room/modifyassistant"),

	LIVE_REMOVE_ASSISTANT("/wxaapi/broadcast/room/removeassistant"),

	LIVE_GET_ASSISTANT_LIST("/wxaapi/broadcast/room/getassistantlist"),

	LIVE_ADD_SUBANCHOR("/wxaapi/broadcast/room/addsubanchor"),

	LIVE_MODIFY_SUBANCHOR("/wxaapi/broadcast/room/modifysubanchor"),

	LIVE_DEL_SUBANCHOR("/wxaapi/broadcast/room/deletesubanchor"),

	LIVE_GET_SUBANCHOR("/wxaapi/broadcast/room/getsubanchor"),

	LIVE_UPDATE_FEED_PUBLIC("/wxaapi/broadcast/room/updatefeedpublic"),

	LIVE_UPDATE_REPLAY("/wxaapi/broadcast/room/updatereplay"),

	LIVE_UPDATE_KF("/wxaapi/broadcast/room/updatekf"),

	LIVE_UPDATE_COMMENT("/wxaapi/broadcast/room/updatecomment"),

	LIVE_ADD_ROLE("/wxaapi/broadcast/role/addrole"),

	LIVE_DEL_ROLE("/wxaapi/broadcast/role/deleterole"),

	LIVE_GET_ROLE_LIST("/wxaapi/broadcast/role/getrolelist"),

	LIVE_GOODS_ADD("/wxaapi/broadcast/goods/add"),

	LIVE_GOODS_RESET_AUDIT("/wxaapi/broadcast/goods/resetaudit"),

	LIVE_GOODS_AUDIT("/wxaapi/broadcast/goods/audit"),

	LIVE_GOODS_DEL("/wxaapi/broadcast/goods/delete"),

	LIVE_GOODS_UPDATE("/wxaapi/broadcast/goods/update"),

	LIVE_GOODS_WARAHOUSE("/wxa/business/getgoodswarehouse"),

	LIVE_GOODS_APPROVED("/wxaapi/broadcast/goods/getapproved"),

	;


	private final String api;

}
