package net.javase.wechat.model.req.qr;

import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import net.javase.wechat.model.req.BaseReq;

/**
 * WxaQrCodeReq
 *
 * @author Frank
 */
@Getter
@Setter
@NoArgsConstructor
public class WxaQrCodeReq extends BaseReq {

	/**
	 * 最大32个可见字符，只支持数字，大小写英文以及部分特殊字符
	 */
	private String scene;

	/**
	 * 适用于: wxacode.createQRCode 和 wxacode.get <br>
	 * 扫码进入的小程序页面路径，最大长度 128 字节，不能为空；<br>
	 * 对于小游戏，可以只传入 query 部分，来实现传参效果，<br>
	 * 如：传入 "?foo=bar"，即可在 wx.getLaunchOptionsSync 接口中的 query 参数获取到 {foo:"bar"}
	 */
	private String path;

	/**
	 * 必须是已经发布的小程序存在的页面（否则报错）<br>
	 * 例如 pages/index/index, 根路径前不要填加 /, 不能携带参数（参数请放在scene字段里）<br>
	 * 如果不填写这个字段，默认跳主页面
	 */
	private String page;

	/**
	 * 二维码的宽度，单位 px，最小 280px，最大 1280px
	 */
	private Integer width;

	/**
	 * 自动配置线条颜色，如果颜色依然是黑色，则说明不建议配置主色调，默认 false
	 */
	private Boolean auto_color;

	/**
	 * auto_color 为 false 时生效，使用 rgb 设置颜色 例如 {"r":"xxx","g":"xxx","b":"xxx"} 十进制表示
	 */
	private LineColor line_color;

	/**
	 * 是否需要透明底色，为 true 时，生成透明底色的小程序
	 */
	private Boolean is_hyaline;


	/**
	 * 适用于: wxacode.createQRCode 和 wxacode.get
	 *
	 * @param path 页面路径
	 */
	public WxaQrCodeReq(String path) {
		this.path = path;
	}

	/**
	 * 适用于: wxacode.createQRCode 和 wxacode.get
	 *
	 * @param path  页面路径
	 * @param width 宽度
	 */
	public WxaQrCodeReq(String path, int width) {
		this.path = path;
		this.width = width;
	}

	/**
	 * 适用于: wxacode.getUnlimited
	 *
	 * @param scene 场景值
	 * @param page  页面
	 */
	public WxaQrCodeReq(String scene, String page) {
		this.page = page;
		this.scene = scene;
	}

	/**
	 * 适用于: wxacode.getUnlimited
	 *
	 * @param scene 场景值
	 * @param page  页面
	 * @param width 宽度
	 */
	public WxaQrCodeReq(String scene, String page, int width) {
		this.page = page;
		this.scene = scene;
		this.width = width;
	}


}
